#
# Create a high level and a lowlevel funtion to call the K test on one or many entries
#
# Author: youssefd
###############################################################################


####################################
# nway.compare.df(x = dat, phenoData = pdata, formula=y ~ phenotype)
#
# Takes a dataframe of observations (samples in columns and features in rows), 
# a phenoData Object describing the samples and a formula of type x ~ y or x ~ y | block
# Returns a list of kruskal_test results following row order of x
# @param x: a data frame  
#
####################################
nway.compare <- function (x, groups){
	# define group levels
	g <- c()
	g.limit = -1
	for (i in groups) {
		g <- c(g, rep(i, i - g.limit))
		g.limit = i
	}
	
	# shift the limit by 1 to move to the last level 
	g.limit <- g.limit + 1
	# make them as levels	
	g <- factor(c(g, rep(g.limit, ncol(x) - g.limit)))
	# do Kruskal-Wallis test and return p-values
	apply(x, 1, function(e) {kruskal.test(e, g)$p.value})
}




