#
# Create a high level and a lowlevel funtion to call the K test on one or many entries
#
# Author: youssefd
###############################################################################


####################################
# nway.compare.df(x = dat, phenoData = pdata, formula=y ~ phenotype)
#
# Takes a dataframe of observations (samples in columns and features in rows), 
# a phenoData Object describing the samples and a formula of type x ~ y or x ~ y | block
# Returns a list of kruskal_test results following row order of x
# @param x: a data frame  
#
####################################
nway.compare.coin <- function (x, phenoData, formula){
	# get design variables from the formula
	design.variables <- all.vars(formula)
	# if length = 2 then x ~ y; if length = 3 the x ~ y | block
	variates <- design.variables[2:length(design.variables)]
	# the variates are in the first column
	apply(x, 1, function(e) {
		# bind the variate columns to the observation column
		test.data <- cbind(data.frame(phenoData[variates]), data.frame(e))
		# rename the data according to design vriables
		colnames(test.data)[ncol(test.data)] <- design.variables[1]
		# perform KW test
		# Uncomment when coin is included as a dependencie
		#kruskal_test(formula, data = test.data)
		# distribution = approximate(B = 999999)
	})
}
